@@ -32,17 +32,19 @@
 #define CHAR_BIT 8
 #endif
 #undef LONG_BIT
-#define LONG_BIT	(sizeof(long) * CHAR_BIT)	/* maybe 32 or 64 */
+					/** maybe 32 or 64 */
+#define LONG_BIT	(sizeof(long) * CHAR_BIT)
 
-/*
- * idset->min is initialized to END_OF_ID.
- * (You may use idset->max instead of idset->min.)
+/**
+ * @CODE{idset->min} is initialized to #END_OF_ID.
+ * (You may use @CODE{idset->max} instead of @CODE{idset->min}.)
  */
 #define IS_EMPTY(idset)	 ((idset)->min == END_OF_ID ? 1 : 0)
 
-/*
+/** @file
 Idset: usage and memory status
 
+@code
 				idset->set
 				[]
 
@@ -58,31 +60,36 @@ idset_contains(idset, 2) == true
 idset_contains(idset, 3) == false
 
 idset_close(idset)		[]
+@endcode
 
-Idset's index always start from 0 according to the custom of C language.
-I you want to treat 1-20 then you must invoke idset_open() with a argument 21.
+Idset's index always start from 0 according to the custom of C language. <br>
+I you want to treat 1-20 then you @EMPH{must} invoke idset_open() with a argument 21.
 
+@code
         idset = idset_open(21);
         idset_add(idset, 0);            => OK
         idset_add(idset, 1);            => OK
                 ...
         idset_add(idset, 20);           => OK
         idset_add(idset, 21);           => ERROR (idset_add: id is out of range.)
+@endcode
 
-The range of value is from 0 to the maximum value expressible by unsigned integer - 1.
-You should define index as an unsigned integer, and use END_OF_ID like follows:
+The range of value is from 0 to the maximum value expressible by unsigned integer - 1. <br>
+You should define index as an unsigned integer, and use #END_OF_ID like follows:
 
+@code
 	unsigned int id;
 	for (id = idset_first(set); id != END_OF_ID; id = idset_next(set))
 		-- processing about an id --
+@endcode
  */
-/*
+/**
  * bit mask table
  * Prepare all bit mask for performance.
  */
 static unsigned long *bit;
 
-/*
+/**
  * Allocate memory for new idset.
  */
 IDSET *
@@ -105,22 +112,22 @@ idset_open(unsigned int size)
 	idset->min = idset->max = idset->lastid = END_OF_ID;
 	return idset;
 }
-/*
- * Return true if idset is empty.
+/**
+ * Return true if @a idset is empty.
  *
- *	i)	idset	idset structure
- *	r)		1: empty, 0: not empty
+ *	@param[in]	idset	idset structure
+ *	@return		1: empty, 0: not empty
  */
 int
 idset_empty(IDSET *idset)
 {
 	return IS_EMPTY(idset);
 }
-/*
- * Add id to the idset.
+/**
+ * Add @a id to the @a idset.
  *
- *	i)	idset	idset structure
- *	i)	id	id number
+ *	@param[in]	idset	idset structure
+ *	@param[in]	id	id number
  */
 void
 idset_add(IDSET *idset, unsigned int id)
@@ -137,12 +144,12 @@ idset_add(IDSET *idset, unsigned int id)
 	else if (id < idset->min)
 		idset->min = id;
 }
-/*
- * Whether or not idset includes specified id.
+/**
+ * Whether or not @a idset includes specified @a id.
  *
- *	i)	idset	idset structure
- *	i)	id	id number
- *	r)		true: contains, false: doesn't contain
+ *	@param[in]	idset	idset structure
+ *	@param[in]	id	id number
+ *	@return		true: contains, false: doesn't contain
  */
 int
 idset_contains(IDSET *idset, unsigned int id)
@@ -153,11 +160,11 @@ idset_contains(IDSET *idset, unsigned int id)
 		return 0;
 	return (idset->set[id / LONG_BIT] & bit[id % LONG_BIT]) != 0;
 }
-/*
+/**
  * Get first id.
  *
- *      i)      idset   idset structure
- *      r)              id (END_OF_ID: end of id)
+ *      @param[in]      idset   idset structure
+ *      @return              id (#END_OF_ID: end of id)
  *
  */
 unsigned int
@@ -167,11 +174,11 @@ idset_first(IDSET *idset)
 	   because idset->min is initialized with END_OF_ID. */
 	return idset->lastid = idset->min;
 }
-/*
+/**
  * Get next id.
  *
- *      i)      idset   idset structure
- *      r)              id (END_OF_ID: end of id)
+ *      @param[in]      idset   idset structure
+ *      @return              id (#END_OF_ID: end of id)
  *
  */
 unsigned int
@@ -201,11 +208,11 @@ idset_next(IDSET *idset)
 			return idset->lastid = index0 * LONG_BIT + i;
 	die("idset_next: internal error.");
 }
-/*
+/**
  * Return the number of bits.
  *
- *	i)	idset	idset structure
- *	r)		number of bits
+ *	@param[in]	idset	idset structure
+ *	@return		number of bits
  */
 unsigned int
 idset_count(IDSET *idset)
@@ -216,7 +223,7 @@ idset_count(IDSET *idset)
 		count++;
 	return count;
 }
-/*
+/**
  * Free memory for the idset.
  */
 void
